
/* Chrysalide - Outil d'analyse de fichiers binaires
 * keymgn.h - prototypes pour la mise en place et la gestion des clefs cryptographiques
 *
 * Copyright (C) 2016-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _ANALYSIS_DB_KEYMGN_H
#define _ANALYSIS_DB_KEYMGN_H


#include <stdbool.h>


#include "certs.h"



/* Charge en mémoire la définition de l'identité courante. */
void load_identity(bool, x509_entries *);

/* Définit les certificats utilisés pour les échanges internes. */
bool register_standalone_certs(const x509_entries *);

/* Définit les certificats utilisés pour par un serveur. */
bool register_server_cert(const char *, const x509_entries *);

/* Elabore une demande de signature de certificat. */
bool make_client_sign_request(const char *, const x509_entries *);

/* Signe un certificat client pour un accès un serveur donné. */
bool sign_client_request(const char *, const char *, const char *);





#include <stdbool.h>
#include <openssl/rsa.h>


/* Taille des clefs RSA */
#define RSA_USED_SIZE (2048 / 8)


/* S'assure que l'utilisateur dispose de clefs RSA. */
bool ensure_user_has_rsa_keys(void);

/* Charge une clef RSA à partir d'un fichier PEM. */
RSA *load_rsa_key(const char *, bool);

/* Signe une empreinte MD5 à l'aide d'une clef RSA. */
bool sign_md5_hash(RSA *, const unsigned char *, unsigned char *);

/* Vérifie la signature d'une empreinte MD5 avec une clef RSA. */
bool verify_md5_hash(RSA *, const unsigned char *, unsigned char *);



#endif  /* _ANALYSIS_DB_KEYMGN_H */
